@@ -328,6 +328,11 @@ class SFREAD:
                             mult = 'MULTIA0%d' %j
                             shif = 'SHIFTB0%d' %j
                             if mult in pscal.keys():
+# we need to fix the content of pscal for signagroups
+# assuming first entry wins
+                                if (pscal[mult].size > 1):
+                                    pscal[mult] = pscal[mult][0]
+                                    pscal[shif] = pscal[shif][0]
                                 dout = dout * pscal[mult] + pscal[shif]
                             else:
                                 break
